package org.springframework.boot.loader.data;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.RandomAccessFile;
import org.springframework.boot.loader.data.RandomAccessDataFile;

final class FileAccess {
  private final Object monitor = new Object();
  
  private final File file;
  
  private RandomAccessFile randomAccessFile;
  
  private FileAccess(File file) {
    this.file = file;
    openIfNecessary();
  }
  
  private int read(byte[] bytes, long position, int offset, int length) throws IOException {
    synchronized (this.monitor) {
      openIfNecessary();
      this.randomAccessFile.seek(position);
      return this.randomAccessFile.read(bytes, offset, length);
    } 
  }
  
  private void openIfNecessary() {
    if (this.randomAccessFile == null)
      try {
        this.randomAccessFile = new RandomAccessFile(this.file, "r");
      } catch (FileNotFoundException ex) {
        throw new IllegalArgumentException(
            String.format("File %s must exist", new Object[] { this.file.getAbsolutePath() }));
      }  
  }
  
  private void close() throws IOException {
    synchronized (this.monitor) {
      if (this.randomAccessFile != null) {
        this.randomAccessFile.close();
        this.randomAccessFile = null;
      } 
    } 
  }
  
  private int readByte(long position) throws IOException {
    synchronized (this.monitor) {
      openIfNecessary();
      this.randomAccessFile.seek(position);
      return this.randomAccessFile.read();
    } 
  }
}
